==> jc-1.4.0.tar.gz: javax/naming/spi/NamingManager.h <==
// public class javax.naming.spi.NamingManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 15ea04e1d7da936f javax_naming_spi_NamingManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_spi_NamingManager_H_
#define _JC_javax_naming_spi_NamingManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_StringTokenizer$object;
struct _jc_javax_naming_CannotProceedException$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_Name$object;
struct _jc_javax_naming_spi_InitialContextFactoryBuilder$object;
struct _jc_javax_naming_spi_ObjectFactoryBuilder$object;

// Typedefs
typedef struct _jc_javax_naming_spi_NamingManager$sub_refs	_jc_javax_naming_spi_NamingManager$sub_refs;
typedef struct _jc_javax_naming_spi_NamingManager$sub_nonrefs	_jc_javax_naming_spi_NamingManager$sub_nonrefs;
typedef struct _jc_javax_naming_spi_NamingManager$refs	_jc_javax_naming_spi_NamingManager$refs;
typedef struct _jc_javax_naming_spi_NamingManager$nonrefs	_jc_javax_naming_spi_NamingManager$nonrefs;
typedef struct _jc_javax_naming_spi_NamingManager$object	_jc_javax_naming_spi_NamingManager$object;

typedef struct _jc_javax_naming_spi_NamingManager$fields_struct	_jc_javax_naming_spi_NamingManager$fields_struct;
typedef const struct _jc_javax_naming_spi_NamingManager$vmethods	_jc_javax_naming_spi_NamingManager$vmethods;
typedef const struct _jc_javax_naming_spi_NamingManager$vtable	_jc_javax_naming_spi_NamingManager$vtable;
typedef const struct _jc_javax_naming_spi_NamingManager$vtype	_jc_javax_naming_spi_NamingManager$vtype;

// Class fields structure
struct _jc_javax_naming_spi_NamingManager$fields_struct {
	struct _jc_java_lang_String$object	*CPE;
	struct _jc_object	*icfb;
	struct _jc_object	*ofb;
};
extern _jc_javax_naming_spi_NamingManager$fields_struct _jc_javax_naming_spi_NamingManager$class_fields;

// Constructors
extern void _jc_javax_naming_spi_NamingManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_spi_NamingManager$object *);

// Static methods
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getContinuationContext$a51d3b3bc6e0d076(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getInitialContext$fab45899837f5a96(_jc_env *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_NamingManager$method$getObjectInstance$a1b04eb3d4ceabc8(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_java_util_StringTokenizer$object *_jc_javax_naming_spi_NamingManager$method$getPlusPath$2bf52b59694a49e5(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_NamingManager$method$getStateToBind$bfeef2c60f1ca315(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getURLContext$7a28b78ab1647ace(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *);
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getURLContext$4f07b4f883c92ba7(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *);
extern jboolean _jc_javax_naming_spi_NamingManager$method$hasInitialContextFactoryBuilder$e3a10878278915b6(_jc_env *);
extern void _jc_javax_naming_spi_NamingManager$method$setInitialContextFactoryBuilder$bf48fe412959e21e(_jc_env *, struct _jc_object *);
extern void _jc_javax_naming_spi_NamingManager$method$setObjectFactoryBuilder$e14a2c06054e10c4(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_naming_spi_NamingManager$vmethods {
};

// Vtable
struct _jc_javax_naming_spi_NamingManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_spi_NamingManager$vmethods	javax_naming_spi_NamingManager;
};

// Vtype
struct _jc_javax_naming_spi_NamingManager$vtype {
	_jc_type			type;
	_jc_javax_naming_spi_NamingManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_spi_NamingManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_spi_NamingManager$refs {
    _jc_javax_naming_spi_NamingManager$sub_refs	javax_naming_spi_NamingManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_spi_NamingManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_spi_NamingManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_spi_NamingManager$sub_nonrefs	javax_naming_spi_NamingManager;
};

// Object instance structure
struct _jc_javax_naming_spi_NamingManager$object {
	_jc_javax_naming_spi_NamingManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_spi_NamingManager$vtype	*vtype;
	_jc_javax_naming_spi_NamingManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_spi_NamingManager$vtype _jc_javax_naming_spi_NamingManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_spi_NamingManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_spi_NamingManager$class_object;

#endif	/* _JC_javax_naming_spi_NamingManager_H_ */

==> jc-1.4.6.tar.gz: javax/naming/spi/NamingManager.h <==
// public class javax.naming.spi.NamingManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 15ea04e1d7da936f javax_naming_spi_NamingManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_spi_NamingManager_H_
#define _JC_javax_naming_spi_NamingManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_StringTokenizer$object;
struct _jc_javax_naming_CannotProceedException$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_Name$object;
struct _jc_javax_naming_spi_InitialContextFactoryBuilder$object;
struct _jc_javax_naming_spi_ObjectFactoryBuilder$object;

// Typedefs
typedef struct _jc_javax_naming_spi_NamingManager$sub_refs	_jc_javax_naming_spi_NamingManager$sub_refs;
typedef struct _jc_javax_naming_spi_NamingManager$sub_nonrefs	_jc_javax_naming_spi_NamingManager$sub_nonrefs;
typedef struct _jc_javax_naming_spi_NamingManager$refs	_jc_javax_naming_spi_NamingManager$refs;
typedef struct _jc_javax_naming_spi_NamingManager$nonrefs	_jc_javax_naming_spi_NamingManager$nonrefs;
typedef struct _jc_javax_naming_spi_NamingManager$object	_jc_javax_naming_spi_NamingManager$object;

typedef struct _jc_javax_naming_spi_NamingManager$fields_struct	_jc_javax_naming_spi_NamingManager$fields_struct;
typedef const struct _jc_javax_naming_spi_NamingManager$vmethods	_jc_javax_naming_spi_NamingManager$vmethods;
typedef const struct _jc_javax_naming_spi_NamingManager$vtable	_jc_javax_naming_spi_NamingManager$vtable;
typedef const struct _jc_javax_naming_spi_NamingManager$vtype	_jc_javax_naming_spi_NamingManager$vtype;

// Class fields structure
struct _jc_javax_naming_spi_NamingManager$fields_struct {
	struct _jc_java_lang_String$object	*CPE;
	struct _jc_object	*icfb;
	struct _jc_object	*ofb;
};
extern _jc_javax_naming_spi_NamingManager$fields_struct _jc_javax_naming_spi_NamingManager$class_fields;

// Constructors
extern void _jc_javax_naming_spi_NamingManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_spi_NamingManager$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getContinuationContext$a51d3b3bc6e0d076(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getInitialContext$fab45899837f5a96(_jc_env *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_NamingManager$method$getObjectInstance$a1b04eb3d4ceabc8(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_StringTokenizer$object *_jc_javax_naming_spi_NamingManager$method$getPlusPath$2bf52b59694a49e5(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_NamingManager$method$getStateToBind$bfeef2c60f1ca315(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getURLContext$7a28b78ab1647ace(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_spi_NamingManager$method$getURLContext$4f07b4f883c92ba7(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_naming_spi_NamingManager$method$hasInitialContextFactoryBuilder$e3a10878278915b6(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_spi_NamingManager$method$setInitialContextFactoryBuilder$bf48fe412959e21e(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_spi_NamingManager$method$setObjectFactoryBuilder$e14a2c06054e10c4(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_spi_NamingManager$vmethods {
};

// Vtable
struct _jc_javax_naming_spi_NamingManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_spi_NamingManager$vmethods	javax_naming_spi_NamingManager;
};

// Vtype
struct _jc_javax_naming_spi_NamingManager$vtype {
	_jc_type			type;
	_jc_javax_naming_spi_NamingManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_spi_NamingManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_spi_NamingManager$refs {
    _jc_javax_naming_spi_NamingManager$sub_refs	javax_naming_spi_NamingManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_spi_NamingManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_spi_NamingManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_spi_NamingManager$sub_nonrefs	javax_naming_spi_NamingManager;
};

// Object instance structure
struct _jc_javax_naming_spi_NamingManager$object {
	_jc_javax_naming_spi_NamingManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_spi_NamingManager$vtype	*vtype;
	_jc_javax_naming_spi_NamingManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_spi_NamingManager$vtype _jc_javax_naming_spi_NamingManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_spi_NamingManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_spi_NamingManager$class_object;

#endif	/* _JC_javax_naming_spi_NamingManager_H_ */
